.. include:: ../BADGES.rst

Python API Function Summary
===========================

.. autosummary::
    :toctree: _function_autosummary

    tstoolbox.tstoolbox.about
    tstoolbox.tstoolbox.accumulate
    tstoolbox.tstoolbox.add_trend
    tstoolbox.tstoolbox.aggregate
    tstoolbox.tstoolbox.calculate_fdc
    tstoolbox.tstoolbox.calculate_kde
    tstoolbox.tstoolbox.clip
    tstoolbox.tstoolbox.convert
    tstoolbox.tstoolbox.convert_index
    tstoolbox.tstoolbox.convert_index_to_julian
    tstoolbox.tstoolbox.converttz
    tstoolbox.tstoolbox.correlation
    tstoolbox.tstoolbox.createts
    tstoolbox.tstoolbox.date_offset
    tstoolbox.tstoolbox.date_slice
    tstoolbox.tstoolbox.describe
    tstoolbox.tstoolbox.dtw
    tstoolbox.tstoolbox.equation
    tstoolbox.tstoolbox.ewm_window
    tstoolbox.tstoolbox.expanding_window
    tstoolbox.tstoolbox.fill
    tstoolbox.tstoolbox.filter
    tstoolbox.tstoolbox.fit
    tstoolbox.tstoolbox.forecast
    tstoolbox.tstoolbox.gof
    tstoolbox.tstoolbox.lag
    tstoolbox.tstoolbox.normalization
    tstoolbox.tstoolbox.pca
    tstoolbox.tstoolbox.pct_change
    tstoolbox.tstoolbox.peak_detection
    tstoolbox.tstoolbox.pick
    tstoolbox.tstoolbox.plot
    tstoolbox.tstoolbox.rank
    tstoolbox.tstoolbox.read
    tstoolbox.tstoolbox.regression
    tstoolbox.tstoolbox.remove_trend
    tstoolbox.tstoolbox.replace
    tstoolbox.tstoolbox.rolling_window
    tstoolbox.tstoolbox.stack
    tstoolbox.tstoolbox.stdtozrxp
    tstoolbox.tstoolbox.tstopickle
    tstoolbox.tstoolbox.unstack
